@@ -27,9 +27,9 @@
 
 #include <math.h>
 #include <stdlib.h>
-#include <ntqfile.h>
-#include <ntqpainter.h>
-#include <ntqtooltip.h>
+#include <tqfile.h>
+#include <tqpainter.h>
+#include <tqtooltip.h>
 #include <tdelocale.h>
 #include <tdemessagebox.h>
 #include "graphwidget.h"
@@ -543,9 +543,9 @@ void GraphWidget::drawEdge(const TQString& sCaller, const TQString& sCallee,
 	// Draw the edge
 	pEdge->show();
 }
-
-#define PI 3.14159265
-
+#ifndef M_PI
+#define M_PI 3.14159265
+#endif
 /**
  * Sets and computes values used for drawing arrows.
  * Initialises the static ArroInfo structure, which is passed in drawEdge().
@@ -558,7 +558,7 @@ void GraphWidget::setArrowInfo(int nLength, int nDegrees)
 	double dRad;
 	
 	// Turn degrees into radians
-	dRad = ((double)nDegrees) * PI / 180.0;
+	dRad = ((double)nDegrees) * M_PI / 180.0;
 	
 	s_ai.m_dLength = (double)nLength;
 	s_ai.m_dTan = tan(dRad);
